@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /cvsroot/pgpool/pgpool-II/main.c,v 1.45.2.5 2009/08/22 04:19:49 t-ishii Exp $
+ * $Header: /cvsroot/pgpool/pgpool-II/main.c,v 1.45.2.9 2009/11/14 11:35:28 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
@@ -277,7 +277,7 @@ int main(int argc, char **argv)
 		load_hba(hba_file);
 
 	/*
-	 * if a non-switch argument remains, then it should be either "reload", "stop" or "switch"
+	 * If a non-switch argument remains, then it should be either "reload" or "stop".
 	 */
 	if (optind == (argc - 1))
 	{
@@ -763,7 +763,7 @@ static void write_pid_file(void)
 		exit(1);
 	}
 	snprintf(pidbuf, sizeof(pidbuf), "%d", (int)getpid());
-	fwrite(pidbuf, strlen(pidbuf), 1, fd);
+	fwrite(pidbuf, strlen(pidbuf)+1, 1, fd);
 	if (fclose(fd))
 	{
 		pool_error("could not write pid file as %s. reason: %s",
@@ -853,6 +853,7 @@ static int create_inet_domain_socket(const char *hostname, const int port)
 	int status;
 	int one = 1;
 	int len;
+	int backlog;
 
 	fd = socket(AF_INET, SOCK_STREAM, 0);
 	if (fd == -1)
@@ -902,7 +903,11 @@ static int create_inet_domain_socket(const char *hostname, const int port)
 		myexit(1);
 	}
 
-	status = listen(fd, PGPOOLMAXLITSENQUEUELENGTH);
+	backlog = pool_config->num_init_children * 2;
+	if (backlog > PGPOOLMAXLITSENQUEUELENGTH)
+		backlog = PGPOOLMAXLITSENQUEUELENGTH;
+
+	status = listen(fd, backlog);
 	if (status < 0)
 	{
 		pool_error("listen() failed. reason: %s", strerror(errno));
@@ -1570,7 +1575,7 @@ static RETSIGTYPE reap_handler(int sig)
 
 /*
  * Attach zombie processes and restart child processes.
- * reaper() must be called under protecting signals.
+ * reaper() must be called protected from signals.
  */
 static void reaper(void)
 {
@@ -1603,16 +1608,29 @@ static void reaper(void)
 	while ((pid = wait3(&status, WNOHANG, NULL)) > 0)
 #endif
 	{
+		if (WIFSIGNALED(status) && WTERMSIG(status) == SIGSEGV)
+		{
+			/* Child terminated by segmentation fault. Report it */
+			pool_error("Child process %d was terminated by segmentation fault", pid);
+		}
+			
 		/* if exiting child process was PCP handler */
 		if (pid == pcp_pid)
 		{
-			pool_debug("PCP child %d exits with status %d by signal %d", pid, status, WTERMSIG(status));
+			if (WIFSIGNALED(status))
+				pool_debug("PCP child %d exits with status %d by signal %d", pid, status, WTERMSIG(status));
+			else
+				pool_debug("PCP child %d exits with status %d", pid, status);
 
 			pcp_pid = pcp_fork_a_child(pcp_unix_fd, pcp_inet_fd, pcp_conf_file);
 			pool_debug("fork a new PCP child pid %d", pcp_pid);
 			break;
-		} else {
-			pool_debug("child %d exits with status %d by signal %d", pid, status, WTERMSIG(status));
+		} else
+		{
+			if (WIFSIGNALED(status))
+				pool_debug("child %d exits with status %d by signal %d", pid, status, WTERMSIG(status));
+			else
+				pool_debug("child %d exits with status %d", pid, status);
 
 			/* look for exiting child's pid */
 			for (i=0;i<pool_config->num_init_children;i++)
